Skip to contents

Usage

movie_details(movie_id, append_to_response = NULL)

Arguments

movie_id

Required search parameter, internal TMDB identifier for a movie

append_to_response

Optional, comma separated list of endpoints within this namespace, 20 items max (ex: "videos,images")

Value

1 row tibble containing JSON response details of specified movie in columns (25 columns by default, plus any append_to_response)